@@ -1,13 +1,5 @@
 # BinData -- Binary data manipulator.
-# Copyright (c) 2007 - 2016 Dion Mendel.
-
-if RUBY_VERSION <= "1.9"
-  fail "BinData requires ruby >= 1.9.3. Use BinData version 1.8.x instead"
-end
-
-if RUBY_VERSION == "2.1.0" and RUBY_PATCHLEVEL == "0"
-  fail "Ruby 2.1.0p0 has a bug that causes BinData to fail. Upgrade your ruby version"
-end
+# Copyright (c) 2007 - 2018 Dion Mendel.
 
 require 'bindata/version'
 require 'bindata/array'
@@ -26,6 +18,7 @@ require 'bindata/string'
 require 'bindata/stringz'
 require 'bindata/struct'
 require 'bindata/trace'
+require 'bindata/uint8_array'
 require 'bindata/virtual'
 require 'bindata/alignment'
 require 'bindata/warnings'
@@ -35,10 +28,10 @@ require 'bindata/warnings'
 # A declarative way to read and write structured binary data.
 # 
 # A full reference manual is available online at
-# http://bindata.rubyforge.org/manual.html
+# https://github.com/dmendel/bindata/wiki
 #
 # == License
 #
 # BinData is released under the same license as Ruby.
 #
-# Copyright (c) 2007 - 2016 Dion Mendel.
+# Copyright (c) 2007 - 2018 Dion Mendel.
